@@ -321,7 +321,7 @@ afterbfd:;
         char *c;
         GString *gs = g_string_new("");
 #ifdef Z_MSC_MINGW
-        *c = z_strcasestr(ziafilename, ".dll");
+        c = z_strcasestr(ziafilename, ".dll");
         if (c) *c = '\0';
 #endif
         c = strrchr(ziafilename, '/');
