@@ -75,10 +75,12 @@ struct zhttpd *zhttpd_init(struct zselect *zsel, int port, int loopback){
 		if (err == EACCES || err == 10013){
 			sin.sin_port = htons(zhttpd->port == 80 ? 8080 : 1024 + zhttpd->port);
 			if (bind(zhttpd->sock, (struct sockaddr *)&sin, sizeof(sin))) {
+				int err = z_sock_errno;
 				zinternal("Can't bind port %d or %d, %s\n", zhttpd->port, ntohs(sin.sin_port), z_sock_strerror());
 				goto x;
 			}
 		}else{
+			int err = z_sock_errno;
 			zinternal("Can't bind port %d, %s\n", zhttpd->port, z_sock_strerror());
 			goto x;
 		}
@@ -220,8 +222,8 @@ void zhttpd_read_handler(void *arg){
     conn->req_data = c + 1;
     g_strlcpy(s, conn->request->str, sizeof(s));
     c = strchr(s, '\r');
-    if (c) *c = '\0';
-    if (*c=='\n') c++;
+    if (c != NULL) *c = '\0';
+    if (c != NULL && *c=='\n') c++;
     dbg("HTTP %s: %s\n", inet_ntoa(conn->peer.sin_addr), s);
 	zselect_set_read(conn->zhttpd->zsel, conn->sock, NULL, arg);
 
@@ -535,6 +537,7 @@ const char *zhttpd_get_mime(char *path){
 	if (strcasecmp(ext, ".css") == 0) return "text/css";
 	if (strcasecmp(ext, ".png") == 0)  return "image/png";
 	if (strcasecmp(ext, ".json") == 0) return "application/json";
+	if (strcasecmp(ext, ".js") == 0) return "text/javascript";
 
 	return "text/plain";
 }
