@@ -1,7 +1,7 @@
 /*
     zserial_proc_pty - portable serial port API
 	Module for PTY process
-    Copyright (C) 2012 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2012-2023 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -49,6 +49,8 @@ static int zserial_proc_pty_open(struct zserial *zser){
         g_free(c);
         exit(-1);
     }
+    zser->opened = 1;
+
     //dbg("zserial_open: forkpty()=%d master=%d\n", zser->pid, zser->master);
     return 0;
 }
@@ -80,7 +82,7 @@ static int zserial_proc_pty_write(struct zserial *zser, void *data, int len){
 
 static int zserial_proc_pty_close(struct zserial *zser){
     int ret = 0;
-    dbg("zserial_close() PTY pid=%d\n");
+    dbg("zserial_close() PTY pid=%d\n", zser->pid);
     if (zser->pid > 0){
         //dbg("kill(%d, %d)\n", zser->pid, SIGTERM);
         kill(zser->pid, SIGTERM);
